@@ -6,7 +6,6 @@ Copyright Ashish Patel, 2021
 
 """
 
-
 import requests
 import ashishdotme_utils_lib.errors.common_errors as ze
 
@@ -23,7 +22,7 @@ class DashboardClient(object):
         """
         self.endpoint = "https://systemapi.prod.ashish.me"
 
-    def _retrieve_data(self, request=None, params=None):
+    def get_data(self, request=None, params=None):
         """
         Retrieve Zotero items via the API
         Combine endpoint and request to access the specific resource
@@ -31,7 +30,7 @@ class DashboardClient(object):
         """
         full_url = "%s%s" % (self.endpoint, request)
         req = requests.get(
-            url=full_url, headers=self.default_headers(), params=params
+            url=full_url, params=params
         )
         self.request.encoding = "utf-8"
         try:
@@ -68,4 +67,5 @@ def error_handler(zot, req):
     else:
         raise ze.HTTPError(err_msg(req))
 
-dashboardClient = DashboardClient()
\ No newline at end of file
+
+dashboardClient = DashboardClient()
